@@ -1,7 +1,13 @@
 #line 1 "inc/Module/Install/Base.pm - /usr/local/share/perl/5.8.4/Module/Install/Base.pm"
 package Module::Install::Base;
 
-#line 28
+# Suspend handler for "redefined" warnings
+BEGIN {
+	my $w = $SIG{__WARN__};
+	$SIG{__WARN__} = sub { $w };
+}
+
+#line 36
 
 sub new {
     my ($class, %args) = @_;
@@ -15,27 +21,28 @@ sub new {
     bless(\%args, $class);
 }
 
-#line 46
+#line 56
 
 sub AUTOLOAD {
     my $self = shift;
-    goto &{$self->_top->autoload};
+
+    local $@;
+    my $autoload = eval { $self->_top->autoload } or return;
+    goto &$autoload;
 }
 
-#line 57
+#line 72
 
 sub _top { $_[0]->{_top} }
 
-#line 68
+#line 85
 
 sub admin {
-    my $self = shift;
-    $self->_top->{admin} or Module::Install::Base::FakeAdmin->new;
+    $_[0]->_top->{admin} or Module::Install::Base::FakeAdmin->new;
 }
 
 sub is_admin {
-    my $self = shift;
-    $self->admin->VERSION;
+    $_[0]->admin->VERSION;
 }
 
 sub DESTROY {}
@@ -44,11 +51,16 @@ package Module::Install::Base::FakeAdmin;
 
 my $Fake;
 sub new { $Fake ||= bless(\@_, $_[0]) }
+
 sub AUTOLOAD {}
+
 sub DESTROY {}
 
+# Restore warning handler
+BEGIN {
+	$SIG{__WARN__} = $SIG{__WARN__}->();
+}
+
 1;
 
-__END__
-
-#line 112
+#line 134
